@@ -18,16 +18,19 @@ class DatabaseSystem:
     MARIADB = 'MariaDB'
 
 
-def run_database_command(client, command):
+def run_database_command(client, command, force_database_name=False):
     """
     Run a database command using the "mysql -e" command
     :param client: String
     :param command: String database command
+    :param force_database_name: Bool forces the database name
     :return:
     """
+    _database_name = ' ' + system.config[client]['db']['name'] if force_database_name else ''
+
     return mode.run_command(
         helper.get_command(client, 'mysql') + ' ' + generate_mysql_credentials(
-            client) + ' -e "' + command + '"',
+            client) + _database_name + ' -e "' + command + '"',
         client, True)
 
 
@@ -41,12 +44,37 @@ def generate_database_dump_filename():
     if system.config['dump_name'] == '':
         # _project-db_20-08-2020_12-37.sql
         _now = datetime.datetime.now()
-        database_dump_file_name = '_' + system.config['origin']['db']['name'] + '_' + _now.strftime(
+        database_dump_file_name = '_' + system.config[mode.Client.ORIGIN]['db']['name'] + '_' + _now.strftime(
             "%d-%m-%Y_%H-%M") + '.sql'
     else:
         database_dump_file_name = system.config['dump_name'] + '.sql'
 
 
+def truncate_tables():
+    """
+    Generate the ignore tables options for the mysqldump command by the given table list
+    # ToDo: Too much conditional nesting
+    :return: String
+    """
+    if 'truncate_table' in system.config:
+        output.message(
+            output.Subject.TARGET,
+            'Truncating tables before import',
+            True
+        )
+        for _table in system.config['truncate_table']:
+            if '*' in _table:
+                _wildcard_tables = get_database_tables_like(mode.Client.TARGET,
+                                                            _table.replace('*', ''))
+                if _wildcard_tables:
+                    for _wildcard_table in _wildcard_tables:
+                        _sql_command = f'TRUNCATE TABLE IF EXISTS {_wildcard_table}'
+                        run_database_command(mode.Client.TARGET, _sql_command, True)
+            else:
+                _sql_command = f'TRUNCATE TABLE IF EXISTS {_table}'
+                run_database_command(mode.Client.TARGET, _sql_command, True)
+
+
 def generate_ignore_database_tables():
     """
     Generate the ignore tables options for the mysqldump command by the given table list
@@ -93,6 +121,21 @@ def get_database_tables_like(client, name):
     return
 
 
+def get_database_tables():
+    """
+    Generate specific tables for export
+    :return: String
+    """
+    if system.config['tables'] == '':
+        return ''
+
+    _result = ''
+    _tables = system.config['tables'].split(',')
+    for _table in _tables:
+        _result += '\'' + _table + '\' '
+    return _result
+
+
 def generate_mysql_credentials(client):
     """
     Generate the needed database credential information for the mysql command
@@ -174,7 +217,7 @@ def get_database_version(client):
     _database_system = None
     _version_number = None
     try:
-        _database_version = run_database_command(mode.Client.ORIGIN, 'SELECT VERSION();').splitlines()[1]
+        _database_version = run_database_command(client, 'SELECT VERSION();').splitlines()[1]
         _database_system = DatabaseSystem.MYSQL
 
         _version_number = re.search('(\d+\.)?(\d+\.)?(\*|\d+)', _database_version).group()
